package Rinci;

our $VERSION = '1.1.78'; # VERSION

1;
# ABSTRACT: Language-neutral metadata for your code

__END__

=pod

=encoding UTF-8

=head1 NAME

Rinci - Language-neutral metadata for your code

=head1 VERSION

This document describes version 1.1.78 of Rinci (from Perl distribution Rinci), released on 2015-09-03.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Rinci>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Rinci>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Rinci>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2015 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
